.. currentmodule:: rimseval.multi_proc

=======================
Multiple File Processor
=======================

In this class, the user can process multiple CRD files simultaneously.
It is mainly intended as an easy interface class for the ``RIMSEvalGUI``.

-------------------------------------------------------
:class:`MultiFileProcessor`: Multi File Processor class
-------------------------------------------------------

.. autoclass:: MultiFileProcessor
    :members:
    :undoc-members:
